@@ -15,6 +15,8 @@ struct udp_sock;
 enum tls_method {
 	TLS_METHOD_SSLV23,
 	TLS_METHOD_DTLSV1,
+	TLS_METHOD_DTLS,      /* DTLS 1.0 and 1.2 */
+	TLS_METHOD_DTLSV1_2,  /* DTLS 1.2 */
 };
 
 enum tls_fingerprint {
@@ -40,6 +42,9 @@ int tls_peer_verify(const struct tls_conn *tc);
 int tls_srtp_keyinfo(const struct tls_conn *tc, enum srtp_suite *suite,
 		     uint8_t *cli_key, size_t cli_key_size,
 		     uint8_t *srv_key, size_t srv_key_size);
+const char *tls_cipher_name(const struct tls_conn *tc);
+int tls_set_ciphers(struct tls *tls, const char *cipherv[], size_t count);
+int tls_set_servername(struct tls_conn *tc, const char *servername);
 
 
 /* TCP */
@@ -61,6 +66,7 @@ int dtls_listen(struct dtls_sock **sockp, const struct sa *laddr,
 		struct udp_sock *us, uint32_t htsize, int layer,
 		dtls_conn_h *connh, void *arg);
 struct udp_sock *dtls_udp_sock(struct dtls_sock *sock);
+void dtls_set_mtu(struct dtls_sock *sock, size_t mtu);
 int dtls_connect(struct tls_conn **ptc, struct tls *tls,
 		 struct dtls_sock *sock, const struct sa *peer,
 		 dtls_estab_h *estabh, dtls_recv_h *recvh,
